@@ -361,9 +361,7 @@ async fn read_node_with_matching_props_on_rel<RequestCtx: RequestContext>(
             &json!({
                 "name": "ORION",
                 "board": {
-                    "props": {
-                        "publicized": false
-                    },
+                    "publicized": false,
                     "dst": {
                         "ScrumBoard": {
                             "NEW": {
@@ -385,9 +383,7 @@ async fn read_node_with_matching_props_on_rel<RequestCtx: RequestContext>(
             &json!({
                 "name": "SPARTAN",
                 "board": {
-                    "props": {
-                        "publicized": true
-                    },
+                    "publicized": true,
                     "dst": {
                         "ScrumBoard": {
                             "NEW": {
@@ -411,9 +407,7 @@ async fn read_node_with_matching_props_on_rel<RequestCtx: RequestContext>(
             name 
             board { 
                 __typename 
-                props {
-                    publicized
-                }
+                publicized
                 dst { 
                     ... on ScrumBoard {
                         __typename 
@@ -425,9 +419,7 @@ async fn read_node_with_matching_props_on_rel<RequestCtx: RequestContext>(
             Some("1234"),
             Some(&json!({
                 "board": {
-                    "props": {
-                        "publicized": true
-                    }
+                    "publicized": true
                 }
             })),
         )
@@ -465,9 +457,7 @@ async fn read_node_with_matching_props_on_rel<RequestCtx: RequestContext>(
             Some("1234"),
             Some(&json!({
                 "board": {
-                    "props": {
-                        "publicized": false
-                    }
+                    "publicized": false
                 }
             })),
         )
@@ -502,9 +492,7 @@ async fn read_node_with_matching_props_on_rel_dst_node<RequestCtx: RequestContex
             &json!({
                 "name": "ORION",
                 "board": {
-                    "props": {
-                        "publicized": false
-                    },
+                    "publicized": false,
                     "dst": {
                         "ScrumBoard": {
                             "NEW": {
@@ -525,9 +513,7 @@ async fn read_node_with_matching_props_on_rel_dst_node<RequestCtx: RequestContex
             &json!({
                 "name": "SPARTAN",
                 "board": {
-                    "props": {
-                        "publicized": false
-                    },
+                    "publicized": false,
                     "dst": {
                         "ScrumBoard": {
                             "NEW": {
